@@ -3,10 +3,12 @@ from __future__ import absolute_import
 from __future__ import division
 
 from compas.topology import breadth_first_traverse
+from compas.topology import connected_components
 
 
 __all__ = [
-    'mesh_is_connected'
+    'mesh_is_connected',
+    'mesh_connected_components'
 ]
 
 
@@ -46,6 +48,10 @@ def mesh_is_connected(mesh):
     return len(nodes) == mesh.number_of_vertices()
 
 
+def mesh_connected_components(mesh):
+    return connected_components(mesh.adjacency)
+
+
 # ==============================================================================
 # Main
 # ==============================================================================
@@ -74,7 +80,3 @@ if __name__ == "__main__":
     m3 = meshes_join([m1, m2])
 
     doctest.testmod()
-
-
-
-
