@@ -2,9 +2,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-
-from .coons import *
-from .tweening import *
+from .coons import *  # noqa: F401 F403
+from .tweening import *  # noqa: F401 F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
