@@ -12,7 +12,6 @@ __all__ = [
     'is_sequence_of_str',
     'is_sequence_of_int',
     'is_sequence_of_float',
-    'is_sequence_of_long',
     'is_sequence_of_tuple',
     'is_sequence_of_list',
     'is_sequence_of_dict',
@@ -22,6 +21,8 @@ __all__ = [
 
     'coerce_sequence_of_tuple',
     'coerce_sequence_of_list',
+
+    'coerce_json',
 ]
 
 
@@ -42,10 +43,6 @@ def is_sequence_of_float(sequence):
     return is_sequence_of_type(sequence, float)
 
 
-def is_sequence_of_long(sequence):
-    return is_sequence_of_type(sequence, long)
-
-
 def is_sequence_of_list(sequence):
     return is_sequence_of_type(sequence, list)
 
@@ -82,7 +79,6 @@ def is_sequence_of_iterable(sequence):
 # coerce
 # ==============================================================================
 
-
 def coerce_sequence_of_tuple(sequence):
     items = []
     for item in sequence:
@@ -111,6 +107,14 @@ def coerce_sequence_of_dict(sequence):
     raise NotImplementedError
 
 
+def coerce_json(path):
+    parts = path.split('.')
+    if parts[-1] != 'json':
+        parts.append('json')
+        path = ".".join(parts)
+    return path
+
+
 # ==============================================================================
 # Main
 # ==============================================================================
